[−][src]Struct validators::base64_url::Base64UrlValidator
Methods
impl Base64UrlValidator[src]
impl Base64UrlValidatorpub fn is_base64_url(&self, base64_url: &str) -> bool[src]
pub fn is_base64_url(&self, base64_url: &str) -> boolpub fn parse_string(&self, base64_url: String) -> Base64UrlResult[src]
pub fn parse_string(&self, base64_url: String) -> Base64UrlResultpub fn parse_str(&self, base64_url: &str) -> Base64UrlResult[src]
pub fn parse_str(&self, base64_url: &str) -> Base64UrlResultTrait Implementations
impl PartialEq<Base64UrlValidator> for Base64UrlValidator[src]
impl PartialEq<Base64UrlValidator> for Base64UrlValidatorfn eq(&self, other: &Base64UrlValidator) -> bool[src]
fn eq(&self, other: &Base64UrlValidator) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
#[must_use]
fn ne(&self, other: &Rhs) -> bool1.0.0
[src]This method tests for !=.
impl Debug for Base64UrlValidator[src]
impl Debug for Base64UrlValidatorAuto Trait Implementations
impl Send for Base64UrlValidator
impl Send for Base64UrlValidatorimpl Sync for Base64UrlValidator
impl Sync for Base64UrlValidatorBlanket Implementations
impl<T, U> Into for T where
U: From<T>, [src]
impl<T, U> Into for T where
U: From<T>, impl<T> From for T[src]
impl<T> From for Timpl<T, U> TryFrom for T where
T: From<U>, [src]
impl<T, U> TryFrom for T where
T: From<U>, type Error = !
🔬 This is a nightly-only experimental API. (
try_from)The type returned in the event of a conversion error.
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>[src]
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>🔬 This is a nightly-only experimental API. (
try_from)Performs the conversion.
impl<T> Borrow for T where
T: ?Sized, [src]
impl<T> Borrow for T where
T: ?Sized, impl<T> BorrowMut for T where
T: ?Sized, [src]
impl<T> BorrowMut for T where
T: ?Sized, fn borrow_mut(&mut self) -> &mut T[src]
fn borrow_mut(&mut self) -> &mut TMutably borrows from an owned value. Read more
impl<T, U> TryInto for T where
U: TryFrom<T>, [src]
impl<T, U> TryInto for T where
U: TryFrom<T>, type Error = <U as TryFrom<T>>::Error
🔬 This is a nightly-only experimental API. (
try_from)The type returned in the event of a conversion error.
fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>[src]
fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>🔬 This is a nightly-only experimental API. (
try_from)Performs the conversion.
impl<T> Any for T where
T: 'static + ?Sized, [src]
impl<T> Any for T where
T: 'static + ?Sized, fn get_type_id(&self) -> TypeId[src]
fn get_type_id(&self) -> TypeId🔬 This is a nightly-only experimental API. (get_type_id)
this method will likely be replaced by an associated static
Gets the TypeId of self. Read more
impl<T> Typeable for T where
T: Any,
impl<T> Typeable for T where
T: Any,