Struct validators::domain::Domain [−][src]
pub struct Domain { /* fields omitted */ }Methods
impl Domain[src]
impl Domainpub fn get_top_level_domain(&self) -> Option<&str>[src]
pub fn get_top_level_domain(&self) -> Option<&str>pub fn get_domain(&self) -> &str[src]
pub fn get_domain(&self) -> &strpub fn get_sub_domain(&self) -> Option<&str>[src]
pub fn get_sub_domain(&self) -> Option<&str>pub fn get_full_domain(&self) -> &str[src]
pub fn get_full_domain(&self) -> &strpub fn get_full_domain_without_port(&self) -> &str[src]
pub fn get_full_domain_without_port(&self) -> &strpub fn get_port(&self) -> Option<DomainPort>[src]
pub fn get_port(&self) -> Option<DomainPort>pub fn is_localhost(&self) -> bool[src]
pub fn is_localhost(&self) -> boolTrait Implementations
impl Clone for Domain[src]
impl Clone for Domainfn clone(&self) -> Domain[src]
fn clone(&self) -> DomainReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Validated for Domain[src]
impl Validated for Domainimpl Debug for Domain[src]
impl Debug for Domainfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Display for Domain[src]
impl Display for Domainfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for Domain[src]
impl PartialEq for Domainfn eq(&self, other: &Self) -> bool[src]
fn eq(&self, other: &Self) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Self) -> bool[src]
fn ne(&self, other: &Self) -> boolThis method tests for !=.
impl From<DomainLocalhostableWithPort> for Domain[src]
impl From<DomainLocalhostableWithPort> for Domainfn from(d: DomainLocalhostableWithPort) -> Self[src]
fn from(d: DomainLocalhostableWithPort) -> SelfPerforms the conversion.
impl PartialEq<Domain> for DomainLocalhostableWithPort[src]
impl PartialEq<Domain> for DomainLocalhostableWithPortfn eq(&self, other: &Domain) -> bool[src]
fn eq(&self, other: &Domain) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Domain) -> bool[src]
fn ne(&self, other: &Domain) -> boolThis method tests for !=.
impl From<DomainLocalhostableAllowPort> for Domain[src]
impl From<DomainLocalhostableAllowPort> for Domainfn from(d: DomainLocalhostableAllowPort) -> Self[src]
fn from(d: DomainLocalhostableAllowPort) -> SelfPerforms the conversion.
impl PartialEq<Domain> for DomainLocalhostableAllowPort[src]
impl PartialEq<Domain> for DomainLocalhostableAllowPortfn eq(&self, other: &Domain) -> bool[src]
fn eq(&self, other: &Domain) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Domain) -> bool[src]
fn ne(&self, other: &Domain) -> boolThis method tests for !=.
impl From<DomainLocalhostableWithoutPort> for Domain[src]
impl From<DomainLocalhostableWithoutPort> for Domainfn from(d: DomainLocalhostableWithoutPort) -> Self[src]
fn from(d: DomainLocalhostableWithoutPort) -> SelfPerforms the conversion.
impl PartialEq<Domain> for DomainLocalhostableWithoutPort[src]
impl PartialEq<Domain> for DomainLocalhostableWithoutPortfn eq(&self, other: &Domain) -> bool[src]
fn eq(&self, other: &Domain) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Domain) -> bool[src]
fn ne(&self, other: &Domain) -> boolThis method tests for !=.
impl From<DomainUnlocalhostableWithPort> for Domain[src]
impl From<DomainUnlocalhostableWithPort> for Domainfn from(d: DomainUnlocalhostableWithPort) -> Self[src]
fn from(d: DomainUnlocalhostableWithPort) -> SelfPerforms the conversion.
impl PartialEq<Domain> for DomainUnlocalhostableWithPort[src]
impl PartialEq<Domain> for DomainUnlocalhostableWithPortfn eq(&self, other: &Domain) -> bool[src]
fn eq(&self, other: &Domain) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Domain) -> bool[src]
fn ne(&self, other: &Domain) -> boolThis method tests for !=.
impl From<DomainUnlocalhostableAllowPort> for Domain[src]
impl From<DomainUnlocalhostableAllowPort> for Domainfn from(d: DomainUnlocalhostableAllowPort) -> Self[src]
fn from(d: DomainUnlocalhostableAllowPort) -> SelfPerforms the conversion.
impl PartialEq<Domain> for DomainUnlocalhostableAllowPort[src]
impl PartialEq<Domain> for DomainUnlocalhostableAllowPortfn eq(&self, other: &Domain) -> bool[src]
fn eq(&self, other: &Domain) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Domain) -> bool[src]
fn ne(&self, other: &Domain) -> boolThis method tests for !=.
impl From<DomainUnlocalhostableWithoutPort> for Domain[src]
impl From<DomainUnlocalhostableWithoutPort> for Domainfn from(d: DomainUnlocalhostableWithoutPort) -> Self[src]
fn from(d: DomainUnlocalhostableWithoutPort) -> SelfPerforms the conversion.
impl PartialEq<Domain> for DomainUnlocalhostableWithoutPort[src]
impl PartialEq<Domain> for DomainUnlocalhostableWithoutPort