[−][src]Struct validators::domain::DomainLocalhostableWithPort
Methods
impl DomainLocalhostableWithPort[src]
impl DomainLocalhostableWithPortpub fn from_string(
full_domain: String
) -> Result<DomainLocalhostableWithPort, DomainError>[src]
pub fn from_string(
full_domain: String
) -> Result<DomainLocalhostableWithPort, DomainError>pub fn from_str(
full_domain: &str
) -> Result<DomainLocalhostableWithPort, DomainError>[src]
pub fn from_str(
full_domain: &str
) -> Result<DomainLocalhostableWithPort, DomainError>pub fn from_domain(
domain: Domain
) -> Result<DomainLocalhostableWithPort, DomainError>[src]
pub fn from_domain(
domain: Domain
) -> Result<DomainLocalhostableWithPort, DomainError>pub fn into_domain(self) -> Domain[src]
pub fn into_domain(self) -> Domainpub fn as_domain(&self) -> &Domain[src]
pub fn as_domain(&self) -> &Domainimpl DomainLocalhostableWithPort[src]
impl DomainLocalhostableWithPortpub fn get_top_level_domain(&self) -> Option<&str>[src]
pub fn get_top_level_domain(&self) -> Option<&str>pub fn get_domain(&self) -> &str[src]
pub fn get_domain(&self) -> &strpub fn get_sub_domain(&self) -> Option<&str>[src]
pub fn get_sub_domain(&self) -> Option<&str>pub fn get_full_domain(&self) -> &str[src]
pub fn get_full_domain(&self) -> &strimpl DomainLocalhostableWithPort[src]
impl DomainLocalhostableWithPortpub fn get_full_domain_without_port(&self) -> &str[src]
pub fn get_full_domain_without_port(&self) -> &strpub fn get_port(&self) -> u16[src]
pub fn get_port(&self) -> u16pub fn is_localhost(&self) -> bool[src]
pub fn is_localhost(&self) -> boolTrait Implementations
impl Validated for DomainLocalhostableWithPort[src]
impl Validated for DomainLocalhostableWithPortimpl ValidatedWrapper for DomainLocalhostableWithPort[src]
impl ValidatedWrapper for DomainLocalhostableWithPorttype Error = DomainError
fn from_string(full_domain: String) -> Result<Self, Self::Error>[src]
fn from_string(full_domain: String) -> Result<Self, Self::Error>fn from_str(full_domain: &str) -> Result<Self, Self::Error>[src]
fn from_str(full_domain: &str) -> Result<Self, Self::Error>impl PartialEq<DomainLocalhostableWithPort> for DomainLocalhostableWithPort[src]
impl PartialEq<DomainLocalhostableWithPort> for DomainLocalhostableWithPortfn eq(&self, other: &DomainLocalhostableWithPort) -> bool[src]
fn eq(&self, other: &DomainLocalhostableWithPort) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &DomainLocalhostableWithPort) -> bool[src]
fn ne(&self, other: &DomainLocalhostableWithPort) -> boolThis method tests for !=.
impl From<DomainLocalhostableWithPort> for Domain[src]
impl From<DomainLocalhostableWithPort> for Domainfn from(d: DomainLocalhostableWithPort) -> Self[src]
fn from(d: DomainLocalhostableWithPort) -> SelfPerforms the conversion.
impl Clone for DomainLocalhostableWithPort[src]
impl Clone for DomainLocalhostableWithPortfn clone(&self) -> DomainLocalhostableWithPort[src]
fn clone(&self) -> DomainLocalhostableWithPortReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Eq for DomainLocalhostableWithPort[src]
impl Eq for DomainLocalhostableWithPortimpl Debug for DomainLocalhostableWithPort[src]
impl Debug for DomainLocalhostableWithPortfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Display for DomainLocalhostableWithPort[src]
impl Display for DomainLocalhostableWithPortfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Hash for DomainLocalhostableWithPort[src]
impl Hash for DomainLocalhostableWithPortfn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl<'a> FromParam<'a> for DomainLocalhostableWithPort[src]
impl<'a> FromParam<'a> for DomainLocalhostableWithPorttype Error = DomainError
The associated error to be returned when parsing fails.
fn from_param(param: &'a RawStr) -> Result<Self, Self::Error>[src]
fn from_param(param: &'a RawStr) -> Result<Self, Self::Error>Parses an instance of Self from a dynamic path parameter string or returns an Error if one cannot be parsed. Read more
impl<'a> FromFormValue<'a> for DomainLocalhostableWithPort[src]
impl<'a> FromFormValue<'a> for DomainLocalhostableWithPorttype Error = DomainError
The associated error which can be returned from parsing. It is a good idea to have the return type be or contain an &'v str so that the unparseable string can be examined after a bad parse. Read more
fn from_form_value(form_value: &'a RawStr) -> Result<Self, Self::Error>[src]
fn from_form_value(form_value: &'a RawStr) -> Result<Self, Self::Error>Parses an instance of Self from an HTTP form field value or returns an Error if one cannot be parsed. Read more
fn default() -> Option<Self>[src]
fn default() -> Option<Self>Returns a default value to be used when the form field does not exist. If this returns None, then the field is required. Otherwise, this should return Some(default_value). The default implementation simply returns None. Read more
impl Serialize for DomainLocalhostableWithPort[src]
impl Serialize for DomainLocalhostableWithPortfn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error> where
S: Serializer, [src]
fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error> where
S: Serializer, Serialize this value into the given Serde serializer. Read more
impl<'de> Deserialize<'de> for DomainLocalhostableWithPort[src]
impl<'de> Deserialize<'de> for DomainLocalhostableWithPortfn deserialize<D>(deserializer: D) -> Result<Self, D::Error> where
D: Deserializer<'de>, [src]
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error> where
D: Deserializer<'de>, Deserialize this value from the given Serde deserializer. Read more