[−][src]Struct validators::domain::DomainValidator
Fields
port: ValidatorOption
localhost: ValidatorOption
Methods
impl DomainValidator[src]
impl DomainValidatorpub fn is_domain(&self, full_domain: &str) -> bool[src]
pub fn is_domain(&self, full_domain: &str) -> boolpub fn parse_string(&self, full_domain: String) -> DomainResult[src]
pub fn parse_string(&self, full_domain: String) -> DomainResultpub fn parse_str(&self, full_domain: &str) -> DomainResult[src]
pub fn parse_str(&self, full_domain: &str) -> DomainResultTrait Implementations
impl PartialEq<DomainValidator> for DomainValidator[src]
impl PartialEq<DomainValidator> for DomainValidatorfn eq(&self, other: &DomainValidator) -> bool[src]
fn eq(&self, other: &DomainValidator) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &DomainValidator) -> bool[src]
fn ne(&self, other: &DomainValidator) -> boolThis method tests for !=.
impl Debug for DomainValidator[src]
impl Debug for DomainValidatorAuto Trait Implementations
impl Send for DomainValidator
impl Send for DomainValidatorimpl Sync for DomainValidator
impl Sync for DomainValidatorBlanket Implementations
impl<T, U> Into for T where
U: From<T>, [src]
impl<T, U> Into for T where
U: From<T>, impl<T> From for T[src]
impl<T> From for Timpl<T, U> TryFrom for T where
T: From<U>, [src]
impl<T, U> TryFrom for T where
T: From<U>, type Error = !
🔬 This is a nightly-only experimental API. (
try_from)The type returned in the event of a conversion error.
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>[src]
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>🔬 This is a nightly-only experimental API. (
try_from)Performs the conversion.
impl<T> Borrow for T where
T: ?Sized, [src]
impl<T> Borrow for T where
T: ?Sized, impl<T> BorrowMut for T where
T: ?Sized, [src]
impl<T> BorrowMut for T where
T: ?Sized, fn borrow_mut(&mut self) -> &mut T[src]
fn borrow_mut(&mut self) -> &mut TMutably borrows from an owned value. Read more
impl<T, U> TryInto for T where
U: TryFrom<T>, [src]
impl<T, U> TryInto for T where
U: TryFrom<T>, type Error = <U as TryFrom<T>>::Error
🔬 This is a nightly-only experimental API. (
try_from)The type returned in the event of a conversion error.
fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>[src]
fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>🔬 This is a nightly-only experimental API. (
try_from)Performs the conversion.
impl<T> Any for T where
T: 'static + ?Sized, [src]
impl<T> Any for T where
T: 'static + ?Sized, fn get_type_id(&self) -> TypeId[src]
fn get_type_id(&self) -> TypeId🔬 This is a nightly-only experimental API. (get_type_id)
this method will likely be replaced by an associated static
Gets the TypeId of self. Read more
impl<T> Typeable for T where
T: Any,
impl<T> Typeable for T where
T: Any,