Enum validators::Base64Error [−][src]
pub enum Base64Error {
Invalid,
PaddingMust,
PaddingNotAllow,
}Variants
the fallback variant
may not be valid but missing the padding part is guaranteed
may not be valid and the padding part seems to exist