Enum validators::Base64UrlDecodedError
source · [−]pub enum Base64UrlDecodedError {
Invalid,
PaddingMust,
PaddingNotAllow,
Decode,
}Variants
Invalid
the fallback variant
PaddingMust
may not be valid but missing the padding part is guaranteed
PaddingNotAllow
may not be valid and the padding part seems to exist
Decode
may be valid but errors happen when decoding (missing padding? having padding?)