Enum validators::DomainError [−][src]
pub enum DomainError {
Invalid,
IPv4Must,
IPv4NotAllow,
LocalMust,
LocalNotAllow,
AtLeastTwoLabelsMust,
AtLeastTwoLabelsNotAllow,
PortMust,
PortNotAllow,
}Variants
the fallback variant
may not be valid but it is guaranteed that the domain part is not an IPv4
may not be valid but it is guaranteed that the domain part is an IPv4
may not be valid but it is guaranteed that the domain part is not local
may not be valid but it is guaranteed that the domain part is local
may not be valid but it is guaranteed that the domain part has only one label
may not be valid but it is guaranteed that the domain part has at least two labels
may not be valid but missing a port is guaranteed
may not be valid and the port part seems to exist