Enum validators::EmailError
source · pub enum EmailError {
Invalid,
IPMust,
IPNotAllow,
LocalMust,
LocalNotAllow,
AtLeastTwoLabelsMust,
AtLeastTwoLabelsNotAllow,
CommentNotAllow,
}Variants
Invalid
the fallback variant
IPMust
may not be valid but it is guaranteed that the domain part is not an IP
IPNotAllow
may not be valid and the domain part seems to be an IP
LocalMust
may not be valid but it is guaranteed that the domain part is not local
LocalNotAllow
may not be valid but it is guaranteed that the domain part is local
AtLeastTwoLabelsMust
may not be valid but it is guaranteed that the domain part has only one label
AtLeastTwoLabelsNotAllow
may not be valid and the domain part seems to has at least two labels
CommentNotAllow
may not be valid and comments seems to exist