Enum validators::IPv4Error [−][src]
pub enum IPv4Error {
Invalid,
LocalMust,
LocalNotAllow,
PortMust,
PortNotAllow,
}Variants
the fallback variant
may not be valid but it is guaranteed that the IPv4 is not local
may not be valid but it is guaranteed that the IPv4 is local
may not be valid but missing a port is guaranteed
may not be valid and the port part seems to exist