Enum validators::TextError [−][src]
pub enum TextError {
Invalid,
TooLong,
TooShort,
}Variants
may not be valid but it is guaranteed that this text is too long
may not be valid but it is guaranteed that this text is too short