[−][src]Struct validators::http_ftp_url::HttpFtpUrlLocalableWithoutProtocol
Methods
impl HttpFtpUrlLocalableWithoutProtocol[src]
impl HttpFtpUrlLocalableWithoutProtocolpub fn from_string(
full_http_ftp_url: String
) -> Result<HttpFtpUrlLocalableWithoutProtocol, HttpFtpUrlError>[src]
pub fn from_string(
full_http_ftp_url: String
) -> Result<HttpFtpUrlLocalableWithoutProtocol, HttpFtpUrlError>pub fn from_str(
full_http_ftp_url: &str
) -> Result<HttpFtpUrlLocalableWithoutProtocol, HttpFtpUrlError>[src]
pub fn from_str(
full_http_ftp_url: &str
) -> Result<HttpFtpUrlLocalableWithoutProtocol, HttpFtpUrlError>pub fn from_http_ftp_url(
http_ftp_url: HttpFtpUrl
) -> Result<HttpFtpUrlLocalableWithoutProtocol, HttpFtpUrlError>[src]
pub fn from_http_ftp_url(
http_ftp_url: HttpFtpUrl
) -> Result<HttpFtpUrlLocalableWithoutProtocol, HttpFtpUrlError>pub fn into_http_ftp_url(self) -> HttpFtpUrl[src]
pub fn into_http_ftp_url(self) -> HttpFtpUrlpub fn as_http_ftp_url(&self) -> &HttpFtpUrl[src]
pub fn as_http_ftp_url(&self) -> &HttpFtpUrlimpl HttpFtpUrlLocalableWithoutProtocol[src]
impl HttpFtpUrlLocalableWithoutProtocolpub fn get_host(&self) -> &Host[src]
pub fn get_host(&self) -> &Hostpub fn get_path(&self) -> Option<&str>[src]
pub fn get_path(&self) -> Option<&str>pub fn get_query(&self) -> Option<&str>[src]
pub fn get_query(&self) -> Option<&str>pub fn get_fragment(&self) -> Option<&str>[src]
pub fn get_fragment(&self) -> Option<&str>pub fn get_full_http_ftp_url(&self) -> &str[src]
pub fn get_full_http_ftp_url(&self) -> &strpub fn get_full_http_ftp_url_without_query_and_fragment(&self) -> &str[src]
pub fn get_full_http_ftp_url_without_query_and_fragment(&self) -> &strpub fn is_absolute(&self) -> bool[src]
pub fn is_absolute(&self) -> boolimpl HttpFtpUrlLocalableWithoutProtocol[src]
impl HttpFtpUrlLocalableWithoutProtocolTrait Implementations
impl Validated for HttpFtpUrlLocalableWithoutProtocol[src]
impl Validated for HttpFtpUrlLocalableWithoutProtocolimpl ValidatedWrapper for HttpFtpUrlLocalableWithoutProtocol[src]
impl ValidatedWrapper for HttpFtpUrlLocalableWithoutProtocoltype Error = HttpFtpUrlError
fn from_string(full_http_ftp_url: String) -> Result<Self, Self::Error>[src]
fn from_string(full_http_ftp_url: String) -> Result<Self, Self::Error>fn from_str(full_http_ftp_url: &str) -> Result<Self, Self::Error>[src]
fn from_str(full_http_ftp_url: &str) -> Result<Self, Self::Error>impl PartialEq<HttpFtpUrlLocalableWithoutProtocol> for HttpFtpUrlLocalableWithoutProtocol[src]
impl PartialEq<HttpFtpUrlLocalableWithoutProtocol> for HttpFtpUrlLocalableWithoutProtocolfn eq(&self, other: &HttpFtpUrlLocalableWithoutProtocol) -> bool[src]
fn eq(&self, other: &HttpFtpUrlLocalableWithoutProtocol) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &HttpFtpUrlLocalableWithoutProtocol) -> bool[src]
fn ne(&self, other: &HttpFtpUrlLocalableWithoutProtocol) -> boolThis method tests for !=.
impl From<HttpFtpUrlLocalableWithoutProtocol> for HttpFtpUrl[src]
impl From<HttpFtpUrlLocalableWithoutProtocol> for HttpFtpUrlfn from(d: HttpFtpUrlLocalableWithoutProtocol) -> Self[src]
fn from(d: HttpFtpUrlLocalableWithoutProtocol) -> SelfPerforms the conversion.
impl Clone for HttpFtpUrlLocalableWithoutProtocol[src]
impl Clone for HttpFtpUrlLocalableWithoutProtocolfn clone(&self) -> HttpFtpUrlLocalableWithoutProtocol[src]
fn clone(&self) -> HttpFtpUrlLocalableWithoutProtocolReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Eq for HttpFtpUrlLocalableWithoutProtocol[src]
impl Eq for HttpFtpUrlLocalableWithoutProtocolimpl Deref for HttpFtpUrlLocalableWithoutProtocol[src]
impl Deref for HttpFtpUrlLocalableWithoutProtocoltype Target = str
The resulting type after dereferencing.
fn deref(&self) -> &Self::Target[src]
fn deref(&self) -> &Self::TargetDereferences the value.
impl Debug for HttpFtpUrlLocalableWithoutProtocol[src]
impl Debug for HttpFtpUrlLocalableWithoutProtocolfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Display for HttpFtpUrlLocalableWithoutProtocol[src]
impl Display for HttpFtpUrlLocalableWithoutProtocolfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Hash for HttpFtpUrlLocalableWithoutProtocol[src]
impl Hash for HttpFtpUrlLocalableWithoutProtocolfn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl<'a> FromParam<'a> for HttpFtpUrlLocalableWithoutProtocol[src]
impl<'a> FromParam<'a> for HttpFtpUrlLocalableWithoutProtocoltype Error = HttpFtpUrlError
The associated error to be returned when parsing fails.
fn from_param(param: &'a RawStr) -> Result<Self, Self::Error>[src]
fn from_param(param: &'a RawStr) -> Result<Self, Self::Error>Parses an instance of Self from a dynamic path parameter string or returns an Error if one cannot be parsed. Read more
impl<'a> FromFormValue<'a> for HttpFtpUrlLocalableWithoutProtocol[src]
impl<'a> FromFormValue<'a> for HttpFtpUrlLocalableWithoutProtocoltype Error = HttpFtpUrlError
The associated error which can be returned from parsing. It is a good idea to have the return type be or contain an &'v str so that the unparseable string can be examined after a bad parse. Read more
fn from_form_value(form_value: &'a RawStr) -> Result<Self, Self::Error>[src]
fn from_form_value(form_value: &'a RawStr) -> Result<Self, Self::Error>Parses an instance of Self from an HTTP form field value or returns an Error if one cannot be parsed. Read more
fn default() -> Option<Self>[src]
fn default() -> Option<Self>Returns a default value to be used when the form field does not exist. If this returns None, then the field is required. Otherwise, this should return Some(default_value). The default implementation simply returns None. Read more
impl Serialize for HttpFtpUrlLocalableWithoutProtocol[src]
impl Serialize for HttpFtpUrlLocalableWithoutProtocolfn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error> where
S: Serializer, [src]
fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error> where
S: Serializer, Serialize this value into the given Serde serializer. Read more
impl<'de> Deserialize<'de> for HttpFtpUrlLocalableWithoutProtocol[src]
impl<'de> Deserialize<'de> for HttpFtpUrlLocalableWithoutProtocolfn deserialize<D>(deserializer: D) -> Result<Self, D::Error> where
D: Deserializer<'de>, [src]
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error> where
D: Deserializer<'de>, Deserialize this value from the given Serde deserializer. Read more