Struct validators::http_url::HttpUrl [−][src]
pub struct HttpUrl { /* fields omitted */ }Methods
impl HttpUrl[src]
impl HttpUrlpub fn get_protocol(&self) -> Option<&str>[src]
pub fn get_protocol(&self) -> Option<&str>pub fn get_host(&self) -> &Host[src]
pub fn get_host(&self) -> &Hostpub fn get_path(&self) -> Option<&str>[src]
pub fn get_path(&self) -> Option<&str>pub fn get_query(&self) -> Option<&str>[src]
pub fn get_query(&self) -> Option<&str>pub fn get_fragment(&self) -> Option<&str>[src]
pub fn get_fragment(&self) -> Option<&str>pub fn get_full_http_url(&self) -> &str[src]
pub fn get_full_http_url(&self) -> &strpub fn get_full_http_url_without_query_and_fragment(&self) -> &str[src]
pub fn get_full_http_url_without_query_and_fragment(&self) -> &strpub fn is_https(&self) -> bool[src]
pub fn is_https(&self) -> boolpub fn is_local(&self) -> bool[src]
pub fn is_local(&self) -> boolTrait Implementations
impl Clone for HttpUrl[src]
impl Clone for HttpUrlfn clone(&self) -> HttpUrl[src]
fn clone(&self) -> HttpUrlReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0
[src]Performs copy-assignment from source. Read more
impl Validated for HttpUrl[src]
impl Validated for HttpUrlimpl Display for HttpUrl[src]
impl Display for HttpUrlfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for HttpUrl[src]
impl PartialEq for HttpUrlfn eq(&self, other: &Self) -> bool[src]
fn eq(&self, other: &Self) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Self) -> bool[src]
fn ne(&self, other: &Self) -> boolThis method tests for !=.
impl From<HttpUrlLocalableWithProtocol> for HttpUrl[src]
impl From<HttpUrlLocalableWithProtocol> for HttpUrlfn from(d: HttpUrlLocalableWithProtocol) -> Self[src]
fn from(d: HttpUrlLocalableWithProtocol) -> SelfPerforms the conversion.
impl PartialEq<HttpUrl> for HttpUrlLocalableWithProtocol[src]
impl PartialEq<HttpUrl> for HttpUrlLocalableWithProtocolfn eq(&self, other: &HttpUrl) -> bool[src]
fn eq(&self, other: &HttpUrl) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &HttpUrl) -> bool[src]
fn ne(&self, other: &HttpUrl) -> boolThis method tests for !=.
impl From<HttpUrlUnlocalableWithProtocol> for HttpUrl[src]
impl From<HttpUrlUnlocalableWithProtocol> for HttpUrlfn from(d: HttpUrlUnlocalableWithProtocol) -> Self[src]
fn from(d: HttpUrlUnlocalableWithProtocol) -> SelfPerforms the conversion.
impl PartialEq<HttpUrl> for HttpUrlUnlocalableWithProtocol[src]
impl PartialEq<HttpUrl> for HttpUrlUnlocalableWithProtocol