[−][src]Struct validators::http_url::HttpUrlUnlocalableWithoutProtocol
Methods
impl HttpUrlUnlocalableWithoutProtocol[src]
impl HttpUrlUnlocalableWithoutProtocolpub fn from_string(
full_http_url: String
) -> Result<HttpUrlUnlocalableWithoutProtocol, HttpUrlError>[src]
pub fn from_string(
full_http_url: String
) -> Result<HttpUrlUnlocalableWithoutProtocol, HttpUrlError>pub fn from_str(
full_http_url: &str
) -> Result<HttpUrlUnlocalableWithoutProtocol, HttpUrlError>[src]
pub fn from_str(
full_http_url: &str
) -> Result<HttpUrlUnlocalableWithoutProtocol, HttpUrlError>pub fn from_http_url(
http_url: HttpUrl
) -> Result<HttpUrlUnlocalableWithoutProtocol, HttpUrlError>[src]
pub fn from_http_url(
http_url: HttpUrl
) -> Result<HttpUrlUnlocalableWithoutProtocol, HttpUrlError>pub fn into_http_url(self) -> HttpUrl[src]
pub fn into_http_url(self) -> HttpUrlpub fn as_http_url(&self) -> &HttpUrl[src]
pub fn as_http_url(&self) -> &HttpUrlimpl HttpUrlUnlocalableWithoutProtocol[src]
impl HttpUrlUnlocalableWithoutProtocolpub fn get_host(&self) -> &Host[src]
pub fn get_host(&self) -> &Hostpub fn get_path(&self) -> Option<&str>[src]
pub fn get_path(&self) -> Option<&str>pub fn get_query(&self) -> Option<&str>[src]
pub fn get_query(&self) -> Option<&str>pub fn get_fragment(&self) -> Option<&str>[src]
pub fn get_fragment(&self) -> Option<&str>pub fn get_full_http_url(&self) -> &str[src]
pub fn get_full_http_url(&self) -> &strpub fn get_full_http_url_without_query_and_fragment(&self) -> &str[src]
pub fn get_full_http_url_without_query_and_fragment(&self) -> &strpub fn is_https(&self) -> bool[src]
pub fn is_https(&self) -> boolpub fn is_absolute(&self) -> bool[src]
pub fn is_absolute(&self) -> boolTrait Implementations
impl Validated for HttpUrlUnlocalableWithoutProtocol[src]
impl Validated for HttpUrlUnlocalableWithoutProtocolimpl ValidatedWrapper for HttpUrlUnlocalableWithoutProtocol[src]
impl ValidatedWrapper for HttpUrlUnlocalableWithoutProtocoltype Error = HttpUrlError
fn from_string(full_http_url: String) -> Result<Self, Self::Error>[src]
fn from_string(full_http_url: String) -> Result<Self, Self::Error>fn from_str(full_http_url: &str) -> Result<Self, Self::Error>[src]
fn from_str(full_http_url: &str) -> Result<Self, Self::Error>impl PartialEq<HttpUrlUnlocalableWithoutProtocol> for HttpUrlUnlocalableWithoutProtocol[src]
impl PartialEq<HttpUrlUnlocalableWithoutProtocol> for HttpUrlUnlocalableWithoutProtocolfn eq(&self, other: &Self) -> bool[src]
fn eq(&self, other: &Self) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Self) -> bool[src]
fn ne(&self, other: &Self) -> boolThis method tests for !=.
impl PartialEq<HttpUrl> for HttpUrlUnlocalableWithoutProtocol[src]
impl PartialEq<HttpUrl> for HttpUrlUnlocalableWithoutProtocolfn eq(&self, other: &HttpUrl) -> bool[src]
fn eq(&self, other: &HttpUrl) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &HttpUrl) -> bool[src]
fn ne(&self, other: &HttpUrl) -> boolThis method tests for !=.
impl From<HttpUrlUnlocalableWithoutProtocol> for HttpUrl[src]
impl From<HttpUrlUnlocalableWithoutProtocol> for HttpUrlfn from(d: HttpUrlUnlocalableWithoutProtocol) -> Self[src]
fn from(d: HttpUrlUnlocalableWithoutProtocol) -> SelfPerforms the conversion.
impl Clone for HttpUrlUnlocalableWithoutProtocol[src]
impl Clone for HttpUrlUnlocalableWithoutProtocolfn clone(&self) -> HttpUrlUnlocalableWithoutProtocol[src]
fn clone(&self) -> HttpUrlUnlocalableWithoutProtocolReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Eq for HttpUrlUnlocalableWithoutProtocol[src]
impl Eq for HttpUrlUnlocalableWithoutProtocolimpl Debug for HttpUrlUnlocalableWithoutProtocol[src]
impl Debug for HttpUrlUnlocalableWithoutProtocolfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Display for HttpUrlUnlocalableWithoutProtocol[src]
impl Display for HttpUrlUnlocalableWithoutProtocolfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Hash for HttpUrlUnlocalableWithoutProtocol[src]
impl Hash for HttpUrlUnlocalableWithoutProtocolfn hash<H: Hasher>(&self, state: &mut H)[src]
fn hash<H: Hasher>(&self, state: &mut H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl<'a> FromParam<'a> for HttpUrlUnlocalableWithoutProtocol[src]
impl<'a> FromParam<'a> for HttpUrlUnlocalableWithoutProtocoltype Error = HttpUrlError
The associated error to be returned when parsing fails.
fn from_param(param: &'a RawStr) -> Result<Self, Self::Error>[src]
fn from_param(param: &'a RawStr) -> Result<Self, Self::Error>Parses an instance of Self from a dynamic path parameter string or returns an Error if one cannot be parsed. Read more
impl<'a> FromFormValue<'a> for HttpUrlUnlocalableWithoutProtocol[src]
impl<'a> FromFormValue<'a> for HttpUrlUnlocalableWithoutProtocoltype Error = HttpUrlError
The associated error which can be returned from parsing. It is a good idea to have the return type be or contain an &'v str so that the unparseable string can be examined after a bad parse. Read more
fn from_form_value(form_value: &'a RawStr) -> Result<Self, Self::Error>[src]
fn from_form_value(form_value: &'a RawStr) -> Result<Self, Self::Error>Parses an instance of Self from an HTTP form field value or returns an Error if one cannot be parsed. Read more
fn default() -> Option<Self>[src]
fn default() -> Option<Self>Returns a default value to be used when the form field does not exist. If this returns None, then the field is required. Otherwise, this should return Some(default_value). The default implementation simply returns None. Read more
impl Serialize for HttpUrlUnlocalableWithoutProtocol[src]
impl Serialize for HttpUrlUnlocalableWithoutProtocolfn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error> where
S: Serializer, [src]
fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error> where
S: Serializer, Serialize this value into the given Serde serializer. Read more
impl<'de> Deserialize<'de> for HttpUrlUnlocalableWithoutProtocol[src]
impl<'de> Deserialize<'de> for HttpUrlUnlocalableWithoutProtocolfn deserialize<D>(deserializer: D) -> Result<Self, D::Error> where
D: Deserializer<'de>, [src]
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error> where
D: Deserializer<'de>, Deserialize this value from the given Serde deserializer. Read more