Struct validators::ipv4::IPv4 [−][src]
pub struct IPv4 { /* fields omitted */ }Methods
impl IPv4[src]
impl IPv4pub fn get_ipv4_address(&self) -> &Ipv4Addr[src]
pub fn get_ipv4_address(&self) -> &Ipv4Addrpub fn get_port(&self) -> Option<u16>[src]
pub fn get_port(&self) -> Option<u16>pub fn get_full_ipv4(&self) -> &str[src]
pub fn get_full_ipv4(&self) -> &strpub fn get_full_ipv4_without_port(&self) -> &str[src]
pub fn get_full_ipv4_without_port(&self) -> &strpub fn is_local(&self) -> bool[src]
pub fn is_local(&self) -> boolTrait Implementations
impl Clone for IPv4[src]
impl Clone for IPv4fn clone(&self) -> IPv4[src]
fn clone(&self) -> IPv4Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Validated for IPv4[src]
impl Validated for IPv4impl Debug for IPv4[src]
impl Debug for IPv4fn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Display for IPv4[src]
impl Display for IPv4fn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for IPv4[src]
impl PartialEq for IPv4fn eq(&self, other: &Self) -> bool[src]
fn eq(&self, other: &Self) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Self) -> bool[src]
fn ne(&self, other: &Self) -> boolThis method tests for !=.
impl From<IPv4LocalableWithPort> for IPv4[src]
impl From<IPv4LocalableWithPort> for IPv4fn from(d: IPv4LocalableWithPort) -> Self[src]
fn from(d: IPv4LocalableWithPort) -> SelfPerforms the conversion.
impl PartialEq<IPv4> for IPv4LocalableWithPort[src]
impl PartialEq<IPv4> for IPv4LocalableWithPortfn eq(&self, other: &IPv4) -> bool[src]
fn eq(&self, other: &IPv4) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &IPv4) -> bool[src]
fn ne(&self, other: &IPv4) -> boolThis method tests for !=.
impl From<IPv4LocalableAllowPort> for IPv4[src]
impl From<IPv4LocalableAllowPort> for IPv4fn from(d: IPv4LocalableAllowPort) -> Self[src]
fn from(d: IPv4LocalableAllowPort) -> SelfPerforms the conversion.
impl PartialEq<IPv4> for IPv4LocalableAllowPort[src]
impl PartialEq<IPv4> for IPv4LocalableAllowPortfn eq(&self, other: &IPv4) -> bool[src]
fn eq(&self, other: &IPv4) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &IPv4) -> bool[src]
fn ne(&self, other: &IPv4) -> boolThis method tests for !=.
impl From<IPv4LocalableWithoutPort> for IPv4[src]
impl From<IPv4LocalableWithoutPort> for IPv4fn from(d: IPv4LocalableWithoutPort) -> Self[src]
fn from(d: IPv4LocalableWithoutPort) -> SelfPerforms the conversion.
impl PartialEq<IPv4> for IPv4LocalableWithoutPort[src]
impl PartialEq<IPv4> for IPv4LocalableWithoutPortfn eq(&self, other: &IPv4) -> bool[src]
fn eq(&self, other: &IPv4) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &IPv4) -> bool[src]
fn ne(&self, other: &IPv4) -> boolThis method tests for !=.
impl From<IPv4UnlocalableWithPort> for IPv4[src]
impl From<IPv4UnlocalableWithPort> for IPv4fn from(d: IPv4UnlocalableWithPort) -> Self[src]
fn from(d: IPv4UnlocalableWithPort) -> SelfPerforms the conversion.
impl PartialEq<IPv4> for IPv4UnlocalableWithPort[src]
impl PartialEq<IPv4> for IPv4UnlocalableWithPortfn eq(&self, other: &IPv4) -> bool[src]
fn eq(&self, other: &IPv4) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &IPv4) -> bool[src]
fn ne(&self, other: &IPv4) -> boolThis method tests for !=.
impl From<IPv4UnlocalableAllowPort> for IPv4[src]
impl From<IPv4UnlocalableAllowPort> for IPv4fn from(d: IPv4UnlocalableAllowPort) -> Self[src]
fn from(d: IPv4UnlocalableAllowPort) -> SelfPerforms the conversion.
impl PartialEq<IPv4> for IPv4UnlocalableAllowPort[src]
impl PartialEq<IPv4> for IPv4UnlocalableAllowPortfn eq(&self, other: &IPv4) -> bool[src]
fn eq(&self, other: &IPv4) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &IPv4) -> bool[src]
fn ne(&self, other: &IPv4) -> boolThis method tests for !=.
impl From<IPv4UnlocalableWithoutPort> for IPv4[src]
impl From<IPv4UnlocalableWithoutPort> for IPv4fn from(d: IPv4UnlocalableWithoutPort) -> Self[src]
fn from(d: IPv4UnlocalableWithoutPort) -> SelfPerforms the conversion.
impl PartialEq<IPv4> for IPv4UnlocalableWithoutPort[src]
impl PartialEq<IPv4> for IPv4UnlocalableWithoutPort