Struct validators::ipv6::IPv6 [−][src]
pub struct IPv6 { /* fields omitted */ }Methods
impl IPv6[src]
impl IPv6pub fn get_ipv6_address(&self) -> &Ipv6Addr[src]
pub fn get_ipv6_address(&self) -> &Ipv6Addrpub fn get_port(&self) -> Option<u16>[src]
pub fn get_port(&self) -> Option<u16>pub fn get_full_ipv6(&self) -> &str[src]
pub fn get_full_ipv6(&self) -> &strpub fn get_full_ipv6_without_port(&self) -> &str[src]
pub fn get_full_ipv6_without_port(&self) -> &strpub fn is_local(&self) -> bool[src]
pub fn is_local(&self) -> boolTrait Implementations
impl Clone for IPv6[src]
impl Clone for IPv6fn clone(&self) -> IPv6[src]
fn clone(&self) -> IPv6Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Validated for IPv6[src]
impl Validated for IPv6impl Debug for IPv6[src]
impl Debug for IPv6fn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Display for IPv6[src]
impl Display for IPv6fn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for IPv6[src]
impl PartialEq for IPv6fn eq(&self, other: &Self) -> bool[src]
fn eq(&self, other: &Self) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Self) -> bool[src]
fn ne(&self, other: &Self) -> boolThis method tests for !=.
impl From<IPv6LocalableWithPort> for IPv6[src]
impl From<IPv6LocalableWithPort> for IPv6fn from(d: IPv6LocalableWithPort) -> Self[src]
fn from(d: IPv6LocalableWithPort) -> SelfPerforms the conversion.
impl PartialEq<IPv6> for IPv6LocalableWithPort[src]
impl PartialEq<IPv6> for IPv6LocalableWithPortfn eq(&self, other: &IPv6) -> bool[src]
fn eq(&self, other: &IPv6) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &IPv6) -> bool[src]
fn ne(&self, other: &IPv6) -> boolThis method tests for !=.
impl From<IPv6LocalableAllowPort> for IPv6[src]
impl From<IPv6LocalableAllowPort> for IPv6fn from(d: IPv6LocalableAllowPort) -> Self[src]
fn from(d: IPv6LocalableAllowPort) -> SelfPerforms the conversion.
impl PartialEq<IPv6> for IPv6LocalableAllowPort[src]
impl PartialEq<IPv6> for IPv6LocalableAllowPortfn eq(&self, other: &IPv6) -> bool[src]
fn eq(&self, other: &IPv6) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &IPv6) -> bool[src]
fn ne(&self, other: &IPv6) -> boolThis method tests for !=.
impl From<IPv6LocalableWithoutPort> for IPv6[src]
impl From<IPv6LocalableWithoutPort> for IPv6fn from(d: IPv6LocalableWithoutPort) -> Self[src]
fn from(d: IPv6LocalableWithoutPort) -> SelfPerforms the conversion.
impl PartialEq<IPv6> for IPv6LocalableWithoutPort[src]
impl PartialEq<IPv6> for IPv6LocalableWithoutPortfn eq(&self, other: &IPv6) -> bool[src]
fn eq(&self, other: &IPv6) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &IPv6) -> bool[src]
fn ne(&self, other: &IPv6) -> boolThis method tests for !=.
impl From<IPv6UnlocalableWithPort> for IPv6[src]
impl From<IPv6UnlocalableWithPort> for IPv6fn from(d: IPv6UnlocalableWithPort) -> Self[src]
fn from(d: IPv6UnlocalableWithPort) -> SelfPerforms the conversion.
impl PartialEq<IPv6> for IPv6UnlocalableWithPort[src]
impl PartialEq<IPv6> for IPv6UnlocalableWithPortfn eq(&self, other: &IPv6) -> bool[src]
fn eq(&self, other: &IPv6) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &IPv6) -> bool[src]
fn ne(&self, other: &IPv6) -> boolThis method tests for !=.
impl From<IPv6UnlocalableAllowPort> for IPv6[src]
impl From<IPv6UnlocalableAllowPort> for IPv6fn from(d: IPv6UnlocalableAllowPort) -> Self[src]
fn from(d: IPv6UnlocalableAllowPort) -> SelfPerforms the conversion.
impl PartialEq<IPv6> for IPv6UnlocalableAllowPort[src]
impl PartialEq<IPv6> for IPv6UnlocalableAllowPortfn eq(&self, other: &IPv6) -> bool[src]
fn eq(&self, other: &IPv6) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &IPv6) -> bool[src]
fn ne(&self, other: &IPv6) -> boolThis method tests for !=.
impl From<IPv6UnlocalableWithoutPort> for IPv6[src]
impl From<IPv6UnlocalableWithoutPort> for IPv6fn from(d: IPv6UnlocalableWithoutPort) -> Self[src]
fn from(d: IPv6UnlocalableWithoutPort) -> SelfPerforms the conversion.
impl PartialEq<IPv6> for IPv6UnlocalableWithoutPort[src]
impl PartialEq<IPv6> for IPv6UnlocalableWithoutPort