[−][src]Struct validators::mac_address::MacAddressAllowAnyCaseWithColon
Methods
impl MacAddressAllowAnyCaseWithColon[src]
impl MacAddressAllowAnyCaseWithColonpub fn from_string(
full_mac_address: String
) -> Result<MacAddressAllowAnyCaseWithColon, MacAddressError>[src]
pub fn from_string(
full_mac_address: String
) -> Result<MacAddressAllowAnyCaseWithColon, MacAddressError>pub fn from_str(
full_mac_address: &str
) -> Result<MacAddressAllowAnyCaseWithColon, MacAddressError>[src]
pub fn from_str(
full_mac_address: &str
) -> Result<MacAddressAllowAnyCaseWithColon, MacAddressError>pub fn from_mac_address(
mac_address: MacAddress
) -> Result<MacAddressAllowAnyCaseWithColon, MacAddressError>[src]
pub fn from_mac_address(
mac_address: MacAddress
) -> Result<MacAddressAllowAnyCaseWithColon, MacAddressError>pub fn into_mac_address(self) -> MacAddress[src]
pub fn into_mac_address(self) -> MacAddresspub fn as_mac_address(&self) -> &MacAddress[src]
pub fn as_mac_address(&self) -> &MacAddressimpl MacAddressAllowAnyCaseWithColon[src]
impl MacAddressAllowAnyCaseWithColonpub fn get_full_mac_address(&self) -> &str[src]
pub fn get_full_mac_address(&self) -> &strimpl MacAddressAllowAnyCaseWithColon[src]
impl MacAddressAllowAnyCaseWithColonpub fn has_lowercase(&self) -> bool[src]
pub fn has_lowercase(&self) -> boolpub fn has_uppercase(&self) -> bool[src]
pub fn has_uppercase(&self) -> boolpub fn has_both_case(&self) -> bool[src]
pub fn has_both_case(&self) -> boolTrait Implementations
impl Validated for MacAddressAllowAnyCaseWithColon[src]
impl Validated for MacAddressAllowAnyCaseWithColonimpl ValidatedWrapper for MacAddressAllowAnyCaseWithColon[src]
impl ValidatedWrapper for MacAddressAllowAnyCaseWithColontype Error = MacAddressError
fn from_string(full_mac_address: String) -> Result<Self, Self::Error>[src]
fn from_string(full_mac_address: String) -> Result<Self, Self::Error>fn from_str(full_mac_address: &str) -> Result<Self, Self::Error>[src]
fn from_str(full_mac_address: &str) -> Result<Self, Self::Error>impl PartialEq<MacAddressAllowAnyCaseWithColon> for MacAddressAllowAnyCaseWithColon[src]
impl PartialEq<MacAddressAllowAnyCaseWithColon> for MacAddressAllowAnyCaseWithColonfn eq(&self, other: &MacAddressAllowAnyCaseWithColon) -> bool[src]
fn eq(&self, other: &MacAddressAllowAnyCaseWithColon) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &MacAddressAllowAnyCaseWithColon) -> bool[src]
fn ne(&self, other: &MacAddressAllowAnyCaseWithColon) -> boolThis method tests for !=.
impl From<MacAddressAllowAnyCaseWithColon> for MacAddress[src]
impl From<MacAddressAllowAnyCaseWithColon> for MacAddressfn from(d: MacAddressAllowAnyCaseWithColon) -> Self[src]
fn from(d: MacAddressAllowAnyCaseWithColon) -> SelfPerforms the conversion.
impl Clone for MacAddressAllowAnyCaseWithColon[src]
impl Clone for MacAddressAllowAnyCaseWithColonfn clone(&self) -> MacAddressAllowAnyCaseWithColon[src]
fn clone(&self) -> MacAddressAllowAnyCaseWithColonReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Eq for MacAddressAllowAnyCaseWithColon[src]
impl Eq for MacAddressAllowAnyCaseWithColonimpl Deref for MacAddressAllowAnyCaseWithColon[src]
impl Deref for MacAddressAllowAnyCaseWithColontype Target = str
The resulting type after dereferencing.
fn deref(&self) -> &Self::Target[src]
fn deref(&self) -> &Self::TargetDereferences the value.
impl Debug for MacAddressAllowAnyCaseWithColon[src]
impl Debug for MacAddressAllowAnyCaseWithColonfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Display for MacAddressAllowAnyCaseWithColon[src]
impl Display for MacAddressAllowAnyCaseWithColonfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Hash for MacAddressAllowAnyCaseWithColon[src]
impl Hash for MacAddressAllowAnyCaseWithColonfn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl<'a> FromParam<'a> for MacAddressAllowAnyCaseWithColon[src]
impl<'a> FromParam<'a> for MacAddressAllowAnyCaseWithColontype Error = MacAddressError
The associated error to be returned when parsing fails.
fn from_param(param: &'a RawStr) -> Result<Self, Self::Error>[src]
fn from_param(param: &'a RawStr) -> Result<Self, Self::Error>Parses an instance of Self from a dynamic path parameter string or returns an Error if one cannot be parsed. Read more
impl<'a> FromFormValue<'a> for MacAddressAllowAnyCaseWithColon[src]
impl<'a> FromFormValue<'a> for MacAddressAllowAnyCaseWithColontype Error = MacAddressError
The associated error which can be returned from parsing. It is a good idea to have the return type be or contain an &'v str so that the unparseable string can be examined after a bad parse. Read more
fn from_form_value(form_value: &'a RawStr) -> Result<Self, Self::Error>[src]
fn from_form_value(form_value: &'a RawStr) -> Result<Self, Self::Error>Parses an instance of Self from an HTTP form field value or returns an Error if one cannot be parsed. Read more
fn default() -> Option<Self>[src]
fn default() -> Option<Self>Returns a default value to be used when the form field does not exist. If this returns None, then the field is required. Otherwise, this should return Some(default_value). The default implementation simply returns None. Read more
impl Serialize for MacAddressAllowAnyCaseWithColon[src]
impl Serialize for MacAddressAllowAnyCaseWithColonfn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error> where
S: Serializer, [src]
fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error> where
S: Serializer, Serialize this value into the given Serde serializer. Read more
impl<'de> Deserialize<'de> for MacAddressAllowAnyCaseWithColon[src]
impl<'de> Deserialize<'de> for MacAddressAllowAnyCaseWithColonfn deserialize<D>(deserializer: D) -> Result<Self, D::Error> where
D: Deserializer<'de>, [src]
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error> where
D: Deserializer<'de>, Deserialize this value from the given Serde deserializer. Read more