[−][src]Struct validators::mac_address::MacAddressUpperCaseWithColon
Methods
impl MacAddressUpperCaseWithColon[src]
impl MacAddressUpperCaseWithColonpub fn from_string(
full_mac_address: String
) -> Result<MacAddressUpperCaseWithColon, MacAddressError>[src]
pub fn from_string(
full_mac_address: String
) -> Result<MacAddressUpperCaseWithColon, MacAddressError>pub fn from_str(
full_mac_address: &str
) -> Result<MacAddressUpperCaseWithColon, MacAddressError>[src]
pub fn from_str(
full_mac_address: &str
) -> Result<MacAddressUpperCaseWithColon, MacAddressError>pub fn from_mac_address(
mac_address: MacAddress
) -> Result<MacAddressUpperCaseWithColon, MacAddressError>[src]
pub fn from_mac_address(
mac_address: MacAddress
) -> Result<MacAddressUpperCaseWithColon, MacAddressError>pub fn into_mac_address(self) -> MacAddress[src]
pub fn into_mac_address(self) -> MacAddresspub fn as_mac_address(&self) -> &MacAddress[src]
pub fn as_mac_address(&self) -> &MacAddressimpl MacAddressUpperCaseWithColon[src]
impl MacAddressUpperCaseWithColonpub fn get_full_mac_address(&self) -> &str[src]
pub fn get_full_mac_address(&self) -> &strTrait Implementations
impl Validated for MacAddressUpperCaseWithColon[src]
impl Validated for MacAddressUpperCaseWithColonimpl ValidatedWrapper for MacAddressUpperCaseWithColon[src]
impl ValidatedWrapper for MacAddressUpperCaseWithColontype Error = MacAddressError
fn from_string(full_mac_address: String) -> Result<Self, Self::Error>[src]
fn from_string(full_mac_address: String) -> Result<Self, Self::Error>fn from_str(full_mac_address: &str) -> Result<Self, Self::Error>[src]
fn from_str(full_mac_address: &str) -> Result<Self, Self::Error>impl PartialEq<MacAddressUpperCaseWithColon> for MacAddressUpperCaseWithColon[src]
impl PartialEq<MacAddressUpperCaseWithColon> for MacAddressUpperCaseWithColonfn eq(&self, other: &MacAddressUpperCaseWithColon) -> bool[src]
fn eq(&self, other: &MacAddressUpperCaseWithColon) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &MacAddressUpperCaseWithColon) -> bool[src]
fn ne(&self, other: &MacAddressUpperCaseWithColon) -> boolThis method tests for !=.
impl From<MacAddressUpperCaseWithColon> for MacAddress[src]
impl From<MacAddressUpperCaseWithColon> for MacAddressfn from(d: MacAddressUpperCaseWithColon) -> Self[src]
fn from(d: MacAddressUpperCaseWithColon) -> SelfPerforms the conversion.
impl Clone for MacAddressUpperCaseWithColon[src]
impl Clone for MacAddressUpperCaseWithColonfn clone(&self) -> MacAddressUpperCaseWithColon[src]
fn clone(&self) -> MacAddressUpperCaseWithColonReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Eq for MacAddressUpperCaseWithColon[src]
impl Eq for MacAddressUpperCaseWithColonimpl Deref for MacAddressUpperCaseWithColon[src]
impl Deref for MacAddressUpperCaseWithColontype Target = str
The resulting type after dereferencing.
fn deref(&self) -> &Self::Target[src]
fn deref(&self) -> &Self::TargetDereferences the value.
impl Debug for MacAddressUpperCaseWithColon[src]
impl Debug for MacAddressUpperCaseWithColonfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Display for MacAddressUpperCaseWithColon[src]
impl Display for MacAddressUpperCaseWithColonfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Hash for MacAddressUpperCaseWithColon[src]
impl Hash for MacAddressUpperCaseWithColonfn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl<'a> FromParam<'a> for MacAddressUpperCaseWithColon[src]
impl<'a> FromParam<'a> for MacAddressUpperCaseWithColontype Error = MacAddressError
The associated error to be returned when parsing fails.
fn from_param(param: &'a RawStr) -> Result<Self, Self::Error>[src]
fn from_param(param: &'a RawStr) -> Result<Self, Self::Error>Parses an instance of Self from a dynamic path parameter string or returns an Error if one cannot be parsed. Read more
impl<'a> FromFormValue<'a> for MacAddressUpperCaseWithColon[src]
impl<'a> FromFormValue<'a> for MacAddressUpperCaseWithColontype Error = MacAddressError
The associated error which can be returned from parsing. It is a good idea to have the return type be or contain an &'v str so that the unparseable string can be examined after a bad parse. Read more
fn from_form_value(form_value: &'a RawStr) -> Result<Self, Self::Error>[src]
fn from_form_value(form_value: &'a RawStr) -> Result<Self, Self::Error>Parses an instance of Self from an HTTP form field value or returns an Error if one cannot be parsed. Read more
fn default() -> Option<Self>[src]
fn default() -> Option<Self>Returns a default value to be used when the form field does not exist. If this returns None, then the field is required. Otherwise, this should return Some(default_value). The default implementation simply returns None. Read more
impl Serialize for MacAddressUpperCaseWithColon[src]
impl Serialize for MacAddressUpperCaseWithColonfn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error> where
S: Serializer, [src]
fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error> where
S: Serializer, Serialize this value into the given Serde serializer. Read more
impl<'de> Deserialize<'de> for MacAddressUpperCaseWithColon[src]
impl<'de> Deserialize<'de> for MacAddressUpperCaseWithColonfn deserialize<D>(deserializer: D) -> Result<Self, D::Error> where
D: Deserializer<'de>, [src]
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error> where
D: Deserializer<'de>, Deserialize this value from the given Serde deserializer. Read more