Struct validators::number::Number
source · pub struct Number { /* private fields */ }Implementations
sourceimpl Number
impl Number
pub fn get_number(&self) -> f64
pub fn is_zero(&self) -> bool
pub fn is_positive(&self) -> bool
pub fn is_negative(&self) -> bool
pub fn is_integer(&self) -> bool
pub unsafe fn from_f64_unchecked(number: f64) -> Number
Methods from Deref<Target = f64>
pub const RADIX: u32 = 2u32
pub const MANTISSA_DIGITS: u32 = 53u32
pub const DIGITS: u32 = 15u32
pub const EPSILON: f64 = 2.2204460492503131E-16f64
pub const MIN: f64 = -1.7976931348623157E+308f64
pub const MIN_POSITIVE: f64 = 2.2250738585072014E-308f64
pub const MAX: f64 = 1.7976931348623157E+308f64
pub const MIN_EXP: i32 = -1_021i32
pub const MAX_EXP: i32 = 1_024i32
pub const MIN_10_EXP: i32 = -307i32
pub const MAX_10_EXP: i32 = 308i32
pub const NAN: f64 = NaNf64
pub const INFINITY: f64 = +Inff64
pub const NEG_INFINITY: f64 = -Inff64
1.62.0 · sourcepub fn total_cmp(&self, other: &f64) -> Ordering
pub fn total_cmp(&self, other: &f64) -> Ordering
Return the ordering between self and other.
Unlike the standard partial comparison between floating point numbers,
this comparison always produces an ordering in accordance to
the totalOrder predicate as defined in the IEEE 754 (2008 revision)
floating point standard. The values are ordered in the following sequence:
- negative quiet NaN
- negative signaling NaN
- negative infinity
- negative numbers
- negative subnormal numbers
- negative zero
- positive zero
- positive subnormal numbers
- positive numbers
- positive infinity
- positive signaling NaN
- positive quiet NaN.
The ordering established by this function does not always agree with the
PartialOrd and PartialEq implementations of f64. For example,
they consider negative and positive zero equal, while total_cmp
doesn’t.
The interpretation of the signaling NaN bit follows the definition in the IEEE 754 standard, which may not match the interpretation by some of the older, non-conformant (e.g. MIPS) hardware implementations.
Example
struct GoodBoy {
name: String,
weight: f64,
}
let mut bois = vec![
GoodBoy { name: "Pucci".to_owned(), weight: 0.1 },
GoodBoy { name: "Woofer".to_owned(), weight: 99.0 },
GoodBoy { name: "Yapper".to_owned(), weight: 10.0 },
GoodBoy { name: "Chonk".to_owned(), weight: f64::INFINITY },
GoodBoy { name: "Abs. Unit".to_owned(), weight: f64::NAN },
GoodBoy { name: "Floaty".to_owned(), weight: -5.0 },
];
bois.sort_by(|a, b| a.weight.total_cmp(&b.weight));Trait Implementations
sourceimpl From<NumberGtZero> for Number
impl From<NumberGtZero> for Number
sourcefn from(d: NumberGtZero) -> Self
fn from(d: NumberGtZero) -> Self
Converts to this type from the input type.
sourceimpl From<NumberGteZero> for Number
impl From<NumberGteZero> for Number
sourcefn from(d: NumberGteZero) -> Self
fn from(d: NumberGteZero) -> Self
Converts to this type from the input type.
sourceimpl From<NumberLtZero> for Number
impl From<NumberLtZero> for Number
sourcefn from(d: NumberLtZero) -> Self
fn from(d: NumberLtZero) -> Self
Converts to this type from the input type.
sourceimpl From<NumberLteZero> for Number
impl From<NumberLteZero> for Number
sourcefn from(d: NumberLteZero) -> Self
fn from(d: NumberLteZero) -> Self
Converts to this type from the input type.
impl Eq for Number
impl StructuralPartialEq for Number
impl Validated for Number