Struct validators::number::NumberAny
source · pub struct NumberAny(_);Implementations
sourceimpl NumberAny
impl NumberAny
pub fn from_string(full_number: String) -> Result<NumberAny, NumberError>
pub fn from_str(full_number: &str) -> Result<NumberAny, NumberError>
pub fn from_number(number: Number) -> Result<NumberAny, NumberError>
pub fn from_f64(value: f64) -> Result<NumberAny, NumberError>
pub fn from_f32(value: f32) -> Result<NumberAny, NumberError>
pub fn from_i8(value: i8) -> Result<NumberAny, NumberError>
pub fn from_i16(value: i16) -> Result<NumberAny, NumberError>
pub fn from_i32(value: i32) -> Result<NumberAny, NumberError>
pub fn from_i64(value: i64) -> Result<NumberAny, NumberError>
pub fn from_i128(value: i128) -> Result<NumberAny, NumberError>
pub fn from_u8(value: u8) -> Result<NumberAny, NumberError>
pub fn from_u16(value: u16) -> Result<NumberAny, NumberError>
pub fn from_u32(value: u32) -> Result<NumberAny, NumberError>
pub fn from_u64(value: u64) -> Result<NumberAny, NumberError>
pub fn from_u128(value: u128) -> Result<NumberAny, NumberError>
pub fn into_number(self) -> Number
pub fn as_number(&self) -> &Number
sourceimpl NumberAny
impl NumberAny
pub fn get_number(&self) -> f64
pub fn is_integer(&self) -> bool
Methods from Deref<Target = f64>
pub const RADIX: u32 = 2u32
pub const MANTISSA_DIGITS: u32 = 53u32
pub const DIGITS: u32 = 15u32
pub const EPSILON: f64 = 2.2204460492503131E-16f64
pub const MIN: f64 = -1.7976931348623157E+308f64
pub const MIN_POSITIVE: f64 = 2.2250738585072014E-308f64
pub const MAX: f64 = 1.7976931348623157E+308f64
pub const MIN_EXP: i32 = -1_021i32
pub const MAX_EXP: i32 = 1_024i32
pub const MIN_10_EXP: i32 = -307i32
pub const MAX_10_EXP: i32 = 308i32
pub const NAN: f64 = NaNf64
pub const INFINITY: f64 = +Inff64
pub const NEG_INFINITY: f64 = -Inff64
1.62.0 · sourcepub fn total_cmp(&self, other: &f64) -> Ordering
pub fn total_cmp(&self, other: &f64) -> Ordering
Return the ordering between self and other.
Unlike the standard partial comparison between floating point numbers,
this comparison always produces an ordering in accordance to
the totalOrder predicate as defined in the IEEE 754 (2008 revision)
floating point standard. The values are ordered in the following sequence:
- negative quiet NaN
- negative signaling NaN
- negative infinity
- negative numbers
- negative subnormal numbers
- negative zero
- positive zero
- positive subnormal numbers
- positive numbers
- positive infinity
- positive signaling NaN
- positive quiet NaN.
The ordering established by this function does not always agree with the
PartialOrd and PartialEq implementations of f64. For example,
they consider negative and positive zero equal, while total_cmp
doesn’t.
The interpretation of the signaling NaN bit follows the definition in the IEEE 754 standard, which may not match the interpretation by some of the older, non-conformant (e.g. MIPS) hardware implementations.
Example
struct GoodBoy {
name: String,
weight: f64,
}
let mut bois = vec![
GoodBoy { name: "Pucci".to_owned(), weight: 0.1 },
GoodBoy { name: "Woofer".to_owned(), weight: 99.0 },
GoodBoy { name: "Yapper".to_owned(), weight: 10.0 },
GoodBoy { name: "Chonk".to_owned(), weight: f64::INFINITY },
GoodBoy { name: "Abs. Unit".to_owned(), weight: f64::NAN },
GoodBoy { name: "Floaty".to_owned(), weight: -5.0 },
];
bois.sort_by(|a, b| a.weight.total_cmp(&b.weight));Trait Implementations
sourceimpl<'de> Deserialize<'de> for NumberAny
impl<'de> Deserialize<'de> for NumberAny
sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl<'a> FromFormValue<'a> for NumberAny
impl<'a> FromFormValue<'a> for NumberAny
type Error = NumberError
type Error = NumberError
The associated error which can be returned from parsing. It is a good
idea to have the return type be or contain an
&'v str so that the
unparseable string can be examined after a bad parse. Read moresourceimpl<'a> FromParam<'a> for NumberAny
impl<'a> FromParam<'a> for NumberAny
type Error = NumberError
type Error = NumberError
The associated error to be returned if parsing/validation fails.
sourceimpl ValidatedWrapper for NumberAny
impl ValidatedWrapper for NumberAny
impl Eq for NumberAny
impl StructuralEq for NumberAny
impl StructuralPartialEq for NumberAny
impl Validated for NumberAny