[−][src]Struct validators::phone_number::PhoneNumber
Methods
impl PhoneNumber[src]
impl PhoneNumberpub fn get_countries(&self) -> &[Id][src]
pub fn get_countries(&self) -> &[Id]pub fn get_full_phone_number(&self) -> &str[src]
pub fn get_full_phone_number(&self) -> &strpub fn into_string(self) -> String[src]
pub fn into_string(self) -> Stringimpl PhoneNumber[src]
impl PhoneNumberpub fn from_string(phone_number: String) -> Result<Self, PhoneNumberError>[src]
pub fn from_string(phone_number: String) -> Result<Self, PhoneNumberError>pub fn from_str(phone_number: &str) -> Result<Self, PhoneNumberError>[src]
pub fn from_str(phone_number: &str) -> Result<Self, PhoneNumberError>Trait Implementations
impl Validated for PhoneNumber[src]
impl Validated for PhoneNumberimpl ValidatedWrapper for PhoneNumber[src]
impl ValidatedWrapper for PhoneNumbertype Error = PhoneNumberError
fn from_string(phone_number: String) -> Result<Self, Self::Error>[src]
fn from_string(phone_number: String) -> Result<Self, Self::Error>fn from_str(phone_number: &str) -> Result<Self, Self::Error>[src]
fn from_str(phone_number: &str) -> Result<Self, Self::Error>impl PartialEq<PhoneNumber> for PhoneNumber[src]
impl PartialEq<PhoneNumber> for PhoneNumberfn eq(&self, other: &PhoneNumber) -> bool[src]
fn eq(&self, other: &PhoneNumber) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &PhoneNumber) -> bool[src]
fn ne(&self, other: &PhoneNumber) -> boolThis method tests for !=.
impl Clone for PhoneNumber[src]
impl Clone for PhoneNumberfn clone(&self) -> PhoneNumber[src]
fn clone(&self) -> PhoneNumberReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Eq for PhoneNumber[src]
impl Eq for PhoneNumberimpl Deref for PhoneNumber[src]
impl Deref for PhoneNumbertype Target = str
The resulting type after dereferencing.
fn deref(&self) -> &Self::Target[src]
fn deref(&self) -> &Self::TargetDereferences the value.
impl Debug for PhoneNumber[src]
impl Debug for PhoneNumberfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Display for PhoneNumber[src]
impl Display for PhoneNumberfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Hash for PhoneNumber[src]
impl Hash for PhoneNumberfn hash<H: Hasher>(&self, state: &mut H)[src]
fn hash<H: Hasher>(&self, state: &mut H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl<'a> FromParam<'a> for PhoneNumber[src]
impl<'a> FromParam<'a> for PhoneNumbertype Error = PhoneNumberError
The associated error to be returned when parsing fails.
fn from_param(param: &'a RawStr) -> Result<Self, Self::Error>[src]
fn from_param(param: &'a RawStr) -> Result<Self, Self::Error>Parses an instance of Self from a dynamic path parameter string or returns an Error if one cannot be parsed. Read more
impl<'a> FromFormValue<'a> for PhoneNumber[src]
impl<'a> FromFormValue<'a> for PhoneNumbertype Error = PhoneNumberError
The associated error which can be returned from parsing. It is a good idea to have the return type be or contain an &'v str so that the unparseable string can be examined after a bad parse. Read more
fn from_form_value(form_value: &'a RawStr) -> Result<Self, Self::Error>[src]
fn from_form_value(form_value: &'a RawStr) -> Result<Self, Self::Error>Parses an instance of Self from an HTTP form field value or returns an Error if one cannot be parsed. Read more
fn default() -> Option<Self>[src]
fn default() -> Option<Self>Returns a default value to be used when the form field does not exist. If this returns None, then the field is required. Otherwise, this should return Some(default_value). The default implementation simply returns None. Read more
impl Serialize for PhoneNumber[src]
impl Serialize for PhoneNumberfn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error> where
S: Serializer, [src]
fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error> where
S: Serializer, Serialize this value into the given Serde serializer. Read more
impl<'de> Deserialize<'de> for PhoneNumber[src]
impl<'de> Deserialize<'de> for PhoneNumberfn deserialize<D>(deserializer: D) -> Result<Self, D::Error> where
D: Deserializer<'de>, [src]
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error> where
D: Deserializer<'de>, Deserialize this value from the given Serde deserializer. Read more