Module validators::prelude::validators_prelude [−][src]
Re-exports
pub use crate::data_encoding; |
pub use crate::idna; |
pub use crate::serde_json; |
pub use crate::phonenumber; |
pub use crate::regex; |
pub use crate::semver; |
pub use crate::url; |
pub use crate::str_utils; |
pub use crate::functions::*; |
pub use crate::models::*; |
Modules
| fmt | Utilities for formatting and printing strings. |
Macros
| format | Creates a |
| serde_if_integer128 | Conditional compilation depending on whether Serde is built with support for 128-bit integers. |
Structs
| BooleanError | |
| Formatter | Configuration for formatting. |
| Ipv4Addr | An IPv4 address. |
| Ipv6Addr | An IPv6 address. |
| RawStr | A reference to a string inside of a raw HTTP message. |
| RegexError | |
| SemVerError | |
| SemVerReqError | |
| Status | Structure representing an HTTP status: an integer code and a reason phrase. |
| String | A UTF-8–encoded, growable string. |
| URLError | |
| Vec | A contiguous growable array type, written as |
Enums
| Base32DecodedError | |
| Base32Error | |
| Base64DecodedError | |
| Base64Error | |
| Base64UrlDecodedError | |
| Base64UrlError | |
| Cow | A clone-on-write smart pointer. |
| DomainError | |
| EmailError | |
| HostError | |
| HttpFtpURLError | |
| HttpURLError | |
| IPError | |
| IPv4Error | |
| IPv6Error | |
| IpAddr | An IP address, either IPv4 or IPv6. |
| JSONError | |
| LengthError | |
| LineError | |
| MacAddressError | |
| NumberError | |
| PhoneError | |
| SignedIntegerError | |
| TextError | |
| UUIDError | |
| UnsignedIntegerError | |
| ValidatorCaseOption | A special kind of options for validators related to the case of characters. |
| ValidatorOption | Options for validators. |
| ValidatorRangeOption | A special kind of options for validators related to ranges. |
| ValidatorSeparatorOption | A special kind of options for validators related to separators. |
Traits
| DeError | The |
| Deserialize | A data structure that can be deserialized from any data format supported by Serde. |
| Deserializer | A data format that can deserialize any data structure supported by Serde. |
| FromFormValue | Trait to parse a typed value from a form value. |
| FromParam | Trait to convert a dynamic path segment string to a concrete value. |
| SeError | Trait used by |
| Serialize | A data structure that can be serialized into any data format supported by Serde. |
| Serializer | A data format that can serialize any data structure supported by Serde. |
| Visitor | This trait represents a visitor that walks through a deserializer. |
Functions
| from_utf8_unchecked⚠ | Converts a slice of bytes to a string slice without checking that the string contains valid UTF-8. |
Derive Macros
| FromFormValue | Derive for the |