[−][src]Struct validators::short_crypt_qr_code_alphanumeric::ShortCryptQRCodeAlphanumeric
Methods
impl ShortCryptQRCodeAlphanumeric[src]
impl ShortCryptQRCodeAlphanumericpub fn get_short_crypt_qr_code_alphanumeric_url(&self) -> &str[src]
pub fn get_short_crypt_qr_code_alphanumeric_url(&self) -> &strpub fn into_string(self) -> String[src]
pub fn into_string(self) -> Stringpub unsafe fn from_string_unchecked(
short_crypt_qr_code_alphanumeric: String
) -> ShortCryptQRCodeAlphanumeric[src]
pub unsafe fn from_string_unchecked(
short_crypt_qr_code_alphanumeric: String
) -> ShortCryptQRCodeAlphanumericimpl ShortCryptQRCodeAlphanumeric[src]
impl ShortCryptQRCodeAlphanumericpub fn from_string(
short_crypt_qr_code_alphanumeric_url: String
) -> Result<Self, ShortCryptQRCodeAlphanumericError>[src]
pub fn from_string(
short_crypt_qr_code_alphanumeric_url: String
) -> Result<Self, ShortCryptQRCodeAlphanumericError>pub fn from_str(
short_crypt_qr_code_alphanumeric_url: &str
) -> Result<Self, ShortCryptQRCodeAlphanumericError>[src]
pub fn from_str(
short_crypt_qr_code_alphanumeric_url: &str
) -> Result<Self, ShortCryptQRCodeAlphanumericError>Trait Implementations
impl Validated for ShortCryptQRCodeAlphanumeric[src]
impl Validated for ShortCryptQRCodeAlphanumericimpl ValidatedWrapper for ShortCryptQRCodeAlphanumeric[src]
impl ValidatedWrapper for ShortCryptQRCodeAlphanumerictype Error = ShortCryptQRCodeAlphanumericError
fn from_string(
short_crypt_qr_code_alphanumeric_url: String
) -> Result<Self, Self::Error>[src]
fn from_string(
short_crypt_qr_code_alphanumeric_url: String
) -> Result<Self, Self::Error>fn from_str(
short_crypt_qr_code_alphanumeric_url: &str
) -> Result<Self, Self::Error>[src]
fn from_str(
short_crypt_qr_code_alphanumeric_url: &str
) -> Result<Self, Self::Error>impl PartialEq<ShortCryptQRCodeAlphanumeric> for ShortCryptQRCodeAlphanumeric[src]
impl PartialEq<ShortCryptQRCodeAlphanumeric> for ShortCryptQRCodeAlphanumericfn eq(&self, other: &ShortCryptQRCodeAlphanumeric) -> bool[src]
fn eq(&self, other: &ShortCryptQRCodeAlphanumeric) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &ShortCryptQRCodeAlphanumeric) -> bool[src]
fn ne(&self, other: &ShortCryptQRCodeAlphanumeric) -> boolThis method tests for !=.
impl Clone for ShortCryptQRCodeAlphanumeric[src]
impl Clone for ShortCryptQRCodeAlphanumericfn clone(&self) -> ShortCryptQRCodeAlphanumeric[src]
fn clone(&self) -> ShortCryptQRCodeAlphanumericReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Eq for ShortCryptQRCodeAlphanumeric[src]
impl Eq for ShortCryptQRCodeAlphanumericimpl Deref for ShortCryptQRCodeAlphanumeric[src]
impl Deref for ShortCryptQRCodeAlphanumerictype Target = str
The resulting type after dereferencing.
fn deref(&self) -> &Self::Target[src]
fn deref(&self) -> &Self::TargetDereferences the value.
impl Debug for ShortCryptQRCodeAlphanumeric[src]
impl Debug for ShortCryptQRCodeAlphanumericfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Display for ShortCryptQRCodeAlphanumeric[src]
impl Display for ShortCryptQRCodeAlphanumericfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Hash for ShortCryptQRCodeAlphanumeric[src]
impl Hash for ShortCryptQRCodeAlphanumericfn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl<'a> FromParam<'a> for ShortCryptQRCodeAlphanumeric[src]
impl<'a> FromParam<'a> for ShortCryptQRCodeAlphanumerictype Error = ShortCryptQRCodeAlphanumericError
The associated error to be returned when parsing fails.
fn from_param(param: &'a RawStr) -> Result<Self, Self::Error>[src]
fn from_param(param: &'a RawStr) -> Result<Self, Self::Error>Parses an instance of Self from a dynamic path parameter string or returns an Error if one cannot be parsed. Read more
impl<'a> FromFormValue<'a> for ShortCryptQRCodeAlphanumeric[src]
impl<'a> FromFormValue<'a> for ShortCryptQRCodeAlphanumerictype Error = ShortCryptQRCodeAlphanumericError
The associated error which can be returned from parsing. It is a good idea to have the return type be or contain an &'v str so that the unparseable string can be examined after a bad parse. Read more
fn from_form_value(form_value: &'a RawStr) -> Result<Self, Self::Error>[src]
fn from_form_value(form_value: &'a RawStr) -> Result<Self, Self::Error>Parses an instance of Self from an HTTP form field value or returns an Error if one cannot be parsed. Read more
fn default() -> Option<Self>[src]
fn default() -> Option<Self>Returns a default value to be used when the form field does not exist. If this returns None, then the field is required. Otherwise, this should return Some(default_value). The default implementation simply returns None. Read more
impl Serialize for ShortCryptQRCodeAlphanumeric[src]
impl Serialize for ShortCryptQRCodeAlphanumericfn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error> where
S: Serializer, [src]
fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error> where
S: Serializer, Serialize this value into the given Serde serializer. Read more
impl<'de> Deserialize<'de> for ShortCryptQRCodeAlphanumeric[src]
impl<'de> Deserialize<'de> for ShortCryptQRCodeAlphanumericfn deserialize<D>(deserializer: D) -> Result<Self, D::Error> where
D: Deserializer<'de>, [src]
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error> where
D: Deserializer<'de>, Deserialize this value from the given Serde deserializer. Read more