[−][src]Struct validators::version::Version
Methods
impl Version[src]
impl Versionpub fn get_full_version(&self) -> &str[src]
pub fn get_full_version(&self) -> &strpub fn get_full_version_without_label(&self) -> &str[src]
pub fn get_full_version_without_label(&self) -> &strpub fn get_label(&self) -> Option<&str>[src]
pub fn get_label(&self) -> Option<&str>pub fn get_major(&self) -> u16[src]
pub fn get_major(&self) -> u16pub fn get_minor(&self) -> Option<u16>[src]
pub fn get_minor(&self) -> Option<u16>pub fn get_patch(&self) -> Option<u16>[src]
pub fn get_patch(&self) -> Option<u16>pub fn into_string(self) -> String[src]
pub fn into_string(self) -> Stringimpl Version[src]
impl Versionpub fn from_string(full_version: String) -> Result<Self, VersionError>[src]
pub fn from_string(full_version: String) -> Result<Self, VersionError>pub fn from_str(full_version: &str) -> Result<Self, VersionError>[src]
pub fn from_str(full_version: &str) -> Result<Self, VersionError>Trait Implementations
impl Validated for Version[src]
impl Validated for Versionimpl ValidatedWrapper for Version[src]
impl ValidatedWrapper for Versiontype Error = VersionError
fn from_string(full_version: String) -> Result<Self, Self::Error>[src]
fn from_string(full_version: String) -> Result<Self, Self::Error>fn from_str(full_version: &str) -> Result<Self, Self::Error>[src]
fn from_str(full_version: &str) -> Result<Self, Self::Error>impl PartialEq<Version> for Version[src]
impl PartialEq<Version> for Versionfn eq(&self, other: &Self) -> bool[src]
fn eq(&self, other: &Self) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Self) -> bool[src]
fn ne(&self, other: &Self) -> boolThis method tests for !=.
impl Clone for Version[src]
impl Clone for Versionfn clone(&self) -> Version[src]
fn clone(&self) -> VersionReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Eq for Version[src]
impl Eq for Versionimpl Debug for Version[src]
impl Debug for Versionfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Display for Version[src]
impl Display for Versionfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Hash for Version[src]
impl Hash for Versionfn hash<H: Hasher>(&self, state: &mut H)[src]
fn hash<H: Hasher>(&self, state: &mut H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl<'a> FromParam<'a> for Version[src]
impl<'a> FromParam<'a> for Versiontype Error = VersionError
The associated error to be returned when parsing fails.
fn from_param(param: &'a RawStr) -> Result<Self, Self::Error>[src]
fn from_param(param: &'a RawStr) -> Result<Self, Self::Error>Parses an instance of Self from a dynamic path parameter string or returns an Error if one cannot be parsed. Read more
impl<'a> FromFormValue<'a> for Version[src]
impl<'a> FromFormValue<'a> for Versiontype Error = VersionError
The associated error which can be returned from parsing. It is a good idea to have the return type be or contain an &'v str so that the unparseable string can be examined after a bad parse. Read more
fn from_form_value(form_value: &'a RawStr) -> Result<Self, Self::Error>[src]
fn from_form_value(form_value: &'a RawStr) -> Result<Self, Self::Error>Parses an instance of Self from an HTTP form field value or returns an Error if one cannot be parsed. Read more
fn default() -> Option<Self>[src]
fn default() -> Option<Self>Returns a default value to be used when the form field does not exist. If this returns None, then the field is required. Otherwise, this should return Some(default_value). The default implementation simply returns None. Read more
impl Serialize for Version[src]
impl Serialize for Versionfn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error> where
S: Serializer, [src]
fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error> where
S: Serializer, Serialize this value into the given Serde serializer. Read more
impl<'de> Deserialize<'de> for Version[src]
impl<'de> Deserialize<'de> for Versionfn deserialize<D>(deserializer: D) -> Result<Self, D::Error> where
D: Deserializer<'de>, [src]
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error> where
D: Deserializer<'de>, Deserialize this value from the given Serde deserializer. Read more