Enum validators::EmailError [−][src]
pub enum EmailError {
Invalid,
IPMust,
IPNotAllow,
LocalMust,
LocalNotAllow,
AtLeastTwoLabelsMust,
AtLeastTwoLabelsNotAllow,
CommentNotAllow,
}Variants
the fallback variant
may not be valid but it is guaranteed that the domain part is not an IP
may not be valid and the domain part seems to be an IP
may not be valid but it is guaranteed that the domain part is not local
may not be valid but it is guaranteed that the domain part is local
may not be valid but it is guaranteed that the domain part has only one label
may not be valid and the domain part seems to has at least two labels
may not be valid and comments seems to exist