pub struct Result<T, E, K = ()>(/* private fields */);Expand description
A wrapper of core::result::Result, utilized for specific purposes.
- This struct uses the
FromParamtrait to implement theFromFormFieldtrait (only impl thefrom_valuemethod), allowing it to serve as the error type for subsequent checks. - This struct implements the
Deserializetrait, allowing it to serve as the error type for subsequent checks.
Implementations
Sourceimpl<T, E, K> Result<T, E, K>
impl<T, E, K> Result<T, E, K>
Sourcepub fn into_std_result(self) -> Result<T, E>
pub fn into_std_result(self) -> Result<T, E>
Convert this instance into core::result::Result.
Sourcepub const fn as_std_result(&self) -> &Result<T, E>
pub const fn as_std_result(&self) -> &Result<T, E>
Get the reference of the core::result::Result instance inside this.
Methods from Deref<Target = Result<T, E>>
1.0.0 · Sourcepub fn as_ref(&self) -> Result<&T, &E>
pub fn as_ref(&self) -> Result<&T, &E>
Converts from &Result<T, E> to Result<&T, &E>.
Produces a new Result, containing a reference
into the original, leaving the original in place.
Examples
let x: Result<u32, &str> = Ok(2);
assert_eq!(x.as_ref(), Ok(&2));
let x: Result<u32, &str> = Err("Error");
assert_eq!(x.as_ref(), Err(&"Error"));1.0.0 · Sourcepub fn as_mut(&mut self) -> Result<&mut T, &mut E>
pub fn as_mut(&mut self) -> Result<&mut T, &mut E>
Converts from &mut Result<T, E> to Result<&mut T, &mut E>.
Examples
fn mutate(r: &mut Result<i32, i32>) {
match r.as_mut() {
Ok(v) => *v = 42,
Err(e) => *e = 0,
}
}
let mut x: Result<i32, i32> = Ok(2);
mutate(&mut x);
assert_eq!(x.unwrap(), 42);
let mut x: Result<i32, i32> = Err(13);
mutate(&mut x);
assert_eq!(x.unwrap_err(), 0);1.47.0 · Sourcepub fn as_deref(&self) -> Result<&<T as Deref>::Target, &E>where
T: Deref,
pub fn as_deref(&self) -> Result<&<T as Deref>::Target, &E>where
T: Deref,
Converts from Result<T, E> (or &Result<T, E>) to Result<&<T as Deref>::Target, &E>.
Coerces the Ok variant of the original Result via Deref
and returns the new Result.
Examples
let x: Result<String, u32> = Ok("hello".to_string());
let y: Result<&str, &u32> = Ok("hello");
assert_eq!(x.as_deref(), y);
let x: Result<String, u32> = Err(42);
let y: Result<&str, &u32> = Err(&42);
assert_eq!(x.as_deref(), y);1.47.0 · Sourcepub fn as_deref_mut(&mut self) -> Result<&mut <T as Deref>::Target, &mut E>where
T: DerefMut,
pub fn as_deref_mut(&mut self) -> Result<&mut <T as Deref>::Target, &mut E>where
T: DerefMut,
Converts from Result<T, E> (or &mut Result<T, E>) to Result<&mut <T as DerefMut>::Target, &mut E>.
Coerces the Ok variant of the original Result via DerefMut
and returns the new Result.
Examples
let mut s = "HELLO".to_string();
let mut x: Result<String, u32> = Ok("hello".to_string());
let y: Result<&mut str, &mut u32> = Ok(&mut s);
assert_eq!(x.as_deref_mut().map(|x| { x.make_ascii_uppercase(); x }), y);
let mut i = 42;
let mut x: Result<String, u32> = Err(42);
let y: Result<&mut str, &mut u32> = Err(&mut i);
assert_eq!(x.as_deref_mut().map(|x| { x.make_ascii_uppercase(); x }), y);1.0.0 · Sourcepub fn iter(&self) -> Iter<'_, T>
pub fn iter(&self) -> Iter<'_, T>
Returns an iterator over the possibly contained value.
The iterator yields one value if the result is Result::Ok, otherwise none.
Examples
let x: Result<u32, &str> = Ok(7);
assert_eq!(x.iter().next(), Some(&7));
let x: Result<u32, &str> = Err("nothing!");
assert_eq!(x.iter().next(), None);1.0.0 · Sourcepub fn iter_mut(&mut self) -> IterMut<'_, T>
pub fn iter_mut(&mut self) -> IterMut<'_, T>
Returns a mutable iterator over the possibly contained value.
The iterator yields one value if the result is Result::Ok, otherwise none.
Examples
let mut x: Result<u32, &str> = Ok(7);
match x.iter_mut().next() {
Some(v) => *v = 40,
None => {},
}
assert_eq!(x, Ok(40));
let mut x: Result<u32, &str> = Err("nothing!");
assert_eq!(x.iter_mut().next(), None);Trait Implementations
impl<T: Copy, E: Copy, K: Copy> Copy for Result<T, E, K>
Sourceimpl<'de, T: ValidateString<Error = Base32Error> + ValidateBytes<Error = Base32Error>> Deserialize<'de> for Result<T, Base32Error>
Available on crate features base32 and serde only.
impl<'de, T: ValidateString<Error = Base32Error> + ValidateBytes<Error = Base32Error>> Deserialize<'de> for Result<T, Base32Error>
base32 and serde only.Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Sourceimpl<'de, T: ValidateString<Error = Base32DecodedError> + ValidateBytes<Error = Base32DecodedError>> Deserialize<'de> for Result<T, Base32DecodedError>
Available on crate features base32_decoded and serde only.
impl<'de, T: ValidateString<Error = Base32DecodedError> + ValidateBytes<Error = Base32DecodedError>> Deserialize<'de> for Result<T, Base32DecodedError>
base32_decoded and serde only.Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Sourceimpl<'de, T: ValidateString<Error = Base64Error> + ValidateBytes<Error = Base64Error>> Deserialize<'de> for Result<T, Base64Error>
Available on crate features base64 and serde only.
impl<'de, T: ValidateString<Error = Base64Error> + ValidateBytes<Error = Base64Error>> Deserialize<'de> for Result<T, Base64Error>
base64 and serde only.Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Sourceimpl<'de, T: ValidateString<Error = Base64DecodedError> + ValidateBytes<Error = Base64DecodedError>> Deserialize<'de> for Result<T, Base64DecodedError>
Available on crate features base64_decoded and serde only.
impl<'de, T: ValidateString<Error = Base64DecodedError> + ValidateBytes<Error = Base64DecodedError>> Deserialize<'de> for Result<T, Base64DecodedError>
base64_decoded and serde only.Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Sourceimpl<'de, T: ValidateString<Error = Base64UrlError> + ValidateBytes<Error = Base64UrlError>> Deserialize<'de> for Result<T, Base64UrlError>
Available on crate features base64_url and serde only.
impl<'de, T: ValidateString<Error = Base64UrlError> + ValidateBytes<Error = Base64UrlError>> Deserialize<'de> for Result<T, Base64UrlError>
base64_url and serde only.Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Sourceimpl<'de, T: ValidateString<Error = Base64UrlDecodedError> + ValidateBytes<Error = Base64UrlDecodedError>> Deserialize<'de> for Result<T, Base64UrlDecodedError>
Available on crate features base64_url_decoded and serde only.
impl<'de, T: ValidateString<Error = Base64UrlDecodedError> + ValidateBytes<Error = Base64UrlDecodedError>> Deserialize<'de> for Result<T, Base64UrlDecodedError>
base64_url_decoded and serde only.Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Sourceimpl<'de, T: ValidateString<Error = BitError> + ValidateUnsignedInteger<Error = BitError>> Deserialize<'de> for Result<T, BitError>
Available on crate features bit and serde only.
impl<'de, T: ValidateString<Error = BitError> + ValidateUnsignedInteger<Error = BitError>> Deserialize<'de> for Result<T, BitError>
bit and serde only.Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Sourceimpl<'de, T: ValidateString<Error = BooleanError> + ValidateChar<Error = BooleanError> + ValidateSignedInteger<Error = BooleanError> + ValidateUnsignedInteger<Error = BooleanError> + ValidateBoolean<Error = BooleanError>> Deserialize<'de> for Result<T, BooleanError>
Available on crate features boolean and serde only.
impl<'de, T: ValidateString<Error = BooleanError> + ValidateChar<Error = BooleanError> + ValidateSignedInteger<Error = BooleanError> + ValidateUnsignedInteger<Error = BooleanError> + ValidateBoolean<Error = BooleanError>> Deserialize<'de> for Result<T, BooleanError>
boolean and serde only.Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Sourceimpl<'de, T: ValidateString<Error = ByteError> + ValidateUnsignedInteger<Error = ByteError>> Deserialize<'de> for Result<T, ByteError>
Available on crate features byte and serde only.
impl<'de, T: ValidateString<Error = ByteError> + ValidateUnsignedInteger<Error = ByteError>> Deserialize<'de> for Result<T, ByteError>
byte and serde only.Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Sourceimpl<'de, T: ValidateString<Error = DomainError>> Deserialize<'de> for Result<T, DomainError>
Available on crate features domain and serde only.
impl<'de, T: ValidateString<Error = DomainError>> Deserialize<'de> for Result<T, DomainError>
domain and serde only.Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Sourceimpl<'de, T: ValidateString<Error = EmailError>> Deserialize<'de> for Result<T, EmailError>
Available on crate features email and serde only.
impl<'de, T: ValidateString<Error = EmailError>> Deserialize<'de> for Result<T, EmailError>
email and serde only.Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Sourceimpl<'de, T: ValidateString<Error = HostError>> Deserialize<'de> for Result<T, HostError>
Available on crate features host and serde only.
impl<'de, T: ValidateString<Error = HostError>> Deserialize<'de> for Result<T, HostError>
host and serde only.Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Sourceimpl<'de, T: ValidateString<Error = HttpURLError>> Deserialize<'de> for Result<T, HttpURLError>
Available on crate features http_url and serde only.
impl<'de, T: ValidateString<Error = HttpURLError>> Deserialize<'de> for Result<T, HttpURLError>
http_url and serde only.Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Sourceimpl<'de, T: ValidateString<Error = HttpFtpURLError>> Deserialize<'de> for Result<T, HttpFtpURLError>
Available on crate features http_ftp_url and serde only.
impl<'de, T: ValidateString<Error = HttpFtpURLError>> Deserialize<'de> for Result<T, HttpFtpURLError>
http_ftp_url and serde only.Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Sourceimpl<'de, T: ValidateString<Error = IpError>> Deserialize<'de> for Result<T, IpError>
Available on crate features ip and serde only.
impl<'de, T: ValidateString<Error = IpError>> Deserialize<'de> for Result<T, IpError>
ip and serde only.Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Sourceimpl<'de, T: ValidateString<Error = Ipv4Error>> Deserialize<'de> for Result<T, Ipv4Error>
Available on crate features ipv4 and serde only.
impl<'de, T: ValidateString<Error = Ipv4Error>> Deserialize<'de> for Result<T, Ipv4Error>
ipv4 and serde only.Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Sourceimpl<'de, T: ValidateString<Error = Ipv6Error>> Deserialize<'de> for Result<T, Ipv6Error>
Available on crate features ipv6 and serde only.
impl<'de, T: ValidateString<Error = Ipv6Error>> Deserialize<'de> for Result<T, Ipv6Error>
ipv6 and serde only.Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Sourceimpl<'de, T: ValidateString<Error = JsonError> + ValidateSignedInteger<Error = JsonError> + ValidateUnsignedInteger<Error = JsonError> + ValidateNumber<Error = JsonError> + ValidateBoolean<Error = JsonError> + ValidateJsonValue<Error = JsonError>> Deserialize<'de> for Result<T, JsonError>
Available on crate features json and serde only.
impl<'de, T: ValidateString<Error = JsonError> + ValidateSignedInteger<Error = JsonError> + ValidateUnsignedInteger<Error = JsonError> + ValidateNumber<Error = JsonError> + ValidateBoolean<Error = JsonError> + ValidateJsonValue<Error = JsonError>> Deserialize<'de> for Result<T, JsonError>
json and serde only.Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Sourceimpl<'de, C: CollectionLength + Deserialize<'de>, T: ValidateLength<C, Error = LengthError>> Deserialize<'de> for Result<T, LengthError, C>
Available on crate features length and serde only.
impl<'de, C: CollectionLength + Deserialize<'de>, T: ValidateLength<C, Error = LengthError>> Deserialize<'de> for Result<T, LengthError, C>
length and serde only.Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Sourceimpl<'de, T: ValidateString<Error = LineError>> Deserialize<'de> for Result<T, LineError>
Available on crate features line and serde only.
impl<'de, T: ValidateString<Error = LineError>> Deserialize<'de> for Result<T, LineError>
line and serde only.Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Sourceimpl<'de, T: ValidateString<Error = MacAddressError>> Deserialize<'de> for Result<T, MacAddressError>
Available on crate features mac_address and serde only.
impl<'de, T: ValidateString<Error = MacAddressError>> Deserialize<'de> for Result<T, MacAddressError>
mac_address and serde only.Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Sourceimpl<'de, T: ValidateString<Error = NumberError> + ValidateNumber<Error = NumberError>> Deserialize<'de> for Result<T, NumberError>
Available on crate features number and serde only.
impl<'de, T: ValidateString<Error = NumberError> + ValidateNumber<Error = NumberError>> Deserialize<'de> for Result<T, NumberError>
number and serde only.Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Sourceimpl<'de, T: ValidateString<Error = PhoneError>> Deserialize<'de> for Result<T, PhoneError>
Available on crate features phone and serde only.
impl<'de, T: ValidateString<Error = PhoneError>> Deserialize<'de> for Result<T, PhoneError>
phone and serde only.Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Sourceimpl<'de, T: ValidateString<Error = RegexError>> Deserialize<'de> for Result<T, RegexError>
Available on crate features regex and serde only.
impl<'de, T: ValidateString<Error = RegexError>> Deserialize<'de> for Result<T, RegexError>
regex and serde only.Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Sourceimpl<'de, T: ValidateString<Error = SemverError>> Deserialize<'de> for Result<T, SemverError>
Available on crate feature serde and (crate features semver_req or semver) only.
impl<'de, T: ValidateString<Error = SemverError>> Deserialize<'de> for Result<T, SemverError>
serde and (crate features semver_req or semver) only.Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Sourceimpl<'de, T: ValidateString<Error = SignedIntegerError> + ValidateSignedInteger<Error = SignedIntegerError>> Deserialize<'de> for Result<T, SignedIntegerError>
Available on crate features serde and signed_integer only.
impl<'de, T: ValidateString<Error = SignedIntegerError> + ValidateSignedInteger<Error = SignedIntegerError>> Deserialize<'de> for Result<T, SignedIntegerError>
serde and signed_integer only.Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Sourceimpl<'de, T: ValidateString<Error = TextError>> Deserialize<'de> for Result<T, TextError>
Available on crate features serde and text only.
impl<'de, T: ValidateString<Error = TextError>> Deserialize<'de> for Result<T, TextError>
serde and text only.Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Sourceimpl<'de, T: ValidateString<Error = UnsignedIntegerError> + ValidateUnsignedInteger<Error = UnsignedIntegerError>> Deserialize<'de> for Result<T, UnsignedIntegerError>
Available on crate features serde and unsigned_integer only.
impl<'de, T: ValidateString<Error = UnsignedIntegerError> + ValidateUnsignedInteger<Error = UnsignedIntegerError>> Deserialize<'de> for Result<T, UnsignedIntegerError>
serde and unsigned_integer only.Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Sourceimpl<'de, T: ValidateString<Error = UrlError>> Deserialize<'de> for Result<T, UrlError>
Available on crate features serde and url only.
impl<'de, T: ValidateString<Error = UrlError>> Deserialize<'de> for Result<T, UrlError>
serde and url only.Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Sourceimpl<'de, T: ValidateString<Error = UuidError>> Deserialize<'de> for Result<T, UuidError>
Available on crate features serde and uuid only.
impl<'de, T: ValidateString<Error = UuidError>> Deserialize<'de> for Result<T, UuidError>
serde and uuid only.Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
impl<T: Eq, E: Eq, K: Eq> Eq for Result<T, E, K>
Sourceimpl<T: ValidateJsonValue<Error = E>, E> From<Value> for Result<T, E>
Available on crate feature serde_json only.
impl<T: ValidateJsonValue<Error = E>, E> From<Value> for Result<T, E>
serde_json only.Sourceimpl<'r, T, E> FromFormField<'r> for Result<T, E>
Available on crate feature rocket only.
impl<'r, T, E> FromFormField<'r> for Result<T, E>
rocket only.Sourcefn from_value(v: ValueField<'r>) -> Result<'r, Self>
fn from_value(v: ValueField<'r>) -> Result<'r, Self>
T from a form value field. Read moreSourceimpl<T: ValidateString<Error = E>, E> FromStr for Result<T, E>
impl<T: ValidateString<Error = E>, E> FromStr for Result<T, E>
Sourceimpl<T: Ord, E: Ord, K: Ord> Ord for Result<T, E, K>
impl<T: Ord, E: Ord, K: Ord> Ord for Result<T, E, K>
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Sourceimpl<T: PartialOrd, E: PartialOrd, K: PartialOrd> PartialOrd for Result<T, E, K>
impl<T: PartialOrd, E: PartialOrd, K: PartialOrd> PartialOrd for Result<T, E, K>
impl<T: PartialEq, E: PartialEq, K: PartialEq> StructuralPartialEq for Result<T, E, K>